Task: Sensitive Topics Evaluation
=================================
Description: Task for evaluating a classifier trained to classify the following sensitive topics:
1. Drugs
2. Politics
3. Religion
4. Medical Advice
5. Relationships & Dating / NSFW


Link: https://arxiv.org/abs/2010.07079

Tags: #All
